@@ -61,7 +61,7 @@ class Gem2DebTestCase
     def setup_cleanup
       unless $__gem2deb_tests_cleanup_installed
         at_exit do
-          if ENV['GEM2DEB_TEST_DEBUG']
+          if ENV['DEBUG']
             puts
             puts "======================================================================="
             puts "Temporary test files left in #{Gem2DebTestCase::TMP_DIR} for inspection!"
@@ -140,6 +140,18 @@ class Gem2DebTestCase
     end
   end
 
+  def self.silently
+    if ENV['DEBUG']
+      yield
+    else
+      silence_stream STDOUT do
+        silence_stream STDERR do
+          yield
+        end
+      end
+    end
+  end
+
   # Runs a command with the current (in-development) gem2deb environment
   # loaded. PATH, PERL5LIB and RUBYLIB environment variables are tweaked to
   # make sure that everything that comes from gem2deb has precedence over
